/* G-CTB GNU Contabilidad
 * Copyright (C) 2001 Branly Abendano, EPN Ingenieria Sistemas  
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public  
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of   
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <gtk/gtk.h>

#include "interface.h"
#include "support.h"
#include "frmPlanContable.h"

#include "callbacks.h"
#include "incl.h"
#include <gda-client.h>


Gda_Connection* cnc;
//GdaConnection* cnc; /* Coneccio'n a la base de datos */

int
die (GdaConnection* cnc)
{
  GList* errors;
  GList* node;
  Gda_Error* error;

	errors = gda_connection_get_errors (cnc);
 
 	for (node = g_list_first (errors); node; node = g_list_next (node)) {
     		error = (Gda_Error*) node->data;
      		g_print ("%s\n", gda_error_description (error));
    	}
  	gda_error_list_free (errors);
  	exit (1);
}     

gchar*
list_providers ()
{
  GList* list;
  GList* node;
  Gda_Provider* provider;
  int i = 0;
  gchar* selected = NULL;

  	list = gda_provider_list ();

  	if (!list)  {
      		g_print ("\n*** Error ***\n");
      		exit (1);
    	}
      
  	g_print ("\nEl siguiente %d GDA provider se encuentra disponible:\n",
        g_list_length (list));

	for (node = g_list_first (list); node; node = g_list_next (node)) {
      		provider = (Gda_Provider*) node->data;
      		g_print ("%d: %s\n", ++i, GDA_PROVIDER_NAME (provider));

      		if (i == 1)
        	selected = g_strdup (GDA_PROVIDER_NAME (provider));
    	}
  	gda_provider_free_list (list);
  	return (selected);
}

void
list_tables (Gda_Connection* cnc)
{
  Gda_Recordset* rs;
  Gda_Field* field;
  gint i;
      
  	g_print ("\nAbriendo Esquema de la tabla Para provar coneccion...\n");
  	rs = gda_connection_open_schema (cnc, GDA_Connection_GDCN_SCHEMA_TABLES,
                                         GDA_Connection_no_CONSTRAINT);

  	if (!rs) die (cnc);

  	g_print ("\nEsta base de datos tiene las siguientes tablas:\n");

  	for (gda_recordset_move_first (rs); !gda_recordset_eof (rs); gda_recordset_move_next (rs)) {
      		for (i = 0; i < gda_recordset_rowsize (rs); i++) {
          		field = gda_recordset_field_idx (rs, i);
          		g_print ("%s=%s\t", gda_field_name (field),
                   		gda_stringify_value (NULL, 0, field));
        	}
      		g_print ("\n");
    	}
}


int
main (int argc, char *argv[])
{
  GtkWidget *frmPrincipalContabilidad;
  gchar* provider;
  gchar* dsn = NULL;
  gchar* user = NULL;
  gchar* password = NULL;

  	dsn      = "postgres";
  	user     = "postgres";
  	password = "postgres"; 
  
  	g_print ("\nInicializando...\n");

  	gda_init ("SistemaContabilidad", NULL, argc, argv);

  	cnc = gda_connection_new (gda_corba_get_orb ());

  	provider = list_providers ();
  	g_print ("\nEscogiendo %s...\n", provider);
  	gda_connection_set_provider (cnc, provider);
  	g_print ("\nAbriendo la coneccion...\n");
  
  	gda_connection_open (cnc, dsn, user, password);

  	list_tables (cnc);

  	gnome_init ("SistemaContabilidad", "0.0.1", argc, argv);

  	glade_gnome_init();                        


  	gtk_set_locale ();
  	gtk_init (&argc, &argv);

  	frmPrincipalContabilidad = create_frmPrincipalContabilidad ();
  	gtk_widget_show (frmPrincipalContabilidad);

  	gtk_main ();

  	die (cnc);
  	return 0;
}


